## Changelog

### [0.2.0] 2022-02-09
- Restructure project to use the source layout
- PEP517: Manage project with Poetry as the build backend
- Rename the project to *FRETlabel*
- Migrate photon sampling module to *FRETraj*
- Update docs and tutorials to Juypterbook

### [0.1.0] 2020-11-09
- first release of fluordynamics including the PyMOL plugin *Fluorlabel* and the Monte-Carlo burst sampling algorithm *Fluorburst*
